@@ -4,13 +4,8 @@
 // Copyright (c) 2019 Guillaume Gomez
 //
 
-use gtk::{self, glib};
-
-use gtk::gio::prelude::ApplicationExt;
-use gtk::prelude::{
-    BoxExt, ContainerExt, DialogExt, GridExt, GtkWindowExt, SpinButtonExt, SpinButtonSignals,
-    WidgetExt,
-};
+use gtk::glib;
+use gtk::prelude::*;
 
 use serde_derive::{Deserialize, Serialize};
 
@@ -138,29 +133,27 @@ fn show_error_dialog(fatal: bool, text: &str) {
     });
 
     dialog.set_resizable(false);
-    dialog.show_all();
+    dialog.show();
 }
 
 pub fn build_spin(label: &str, grid: &gtk::Grid, top: i32, refresh: u32) -> gtk::SpinButton {
     // Refresh rate.
-    let refresh_label = gtk::Label::new(Some(label));
+    let refresh_label = gtk::Label::builder()
+        .label(label)
+        .halign(gtk::Align::Start)
+        .hexpand(true)
+        .build();
     // We allow 0.5 to 5 seconds, in 0.1 second steps.
     let refresh_entry = gtk::SpinButton::with_range(0.5, 5., 0.1);
 
-    refresh_label.set_halign(gtk::Align::Start);
-    refresh_entry.set_hexpand(true);
-
-    refresh_entry.set_value(f64::from(refresh) / 1000.);
+    refresh_entry.set_value(f64::from(refresh) / 1_000.);
 
     grid.attach(&refresh_label, 0, top, 1, 1);
     grid.attach(&refresh_entry, 1, top, 3, 1);
     refresh_entry
 }
 
-pub fn show_settings_dialog(
-    settings: &Rc<RefCell<Settings>>,
-    rfs: &Rc<RefCell<RequiredForSettings>>,
-) {
+pub fn show_settings_dialog(settings: &Rc<RefCell<Settings>>, rfs: &RequiredForSettings) {
     let bsettings = &*settings.borrow();
     // Create an empty dialog with close button.
     let dialog = gtk::Dialog::with_buttons(
@@ -171,10 +164,11 @@ pub fn show_settings_dialog(
     );
 
     // All the UI widgets are going to be stored in a grid.
-    let grid = gtk::Grid::new();
-    grid.set_column_spacing(4);
-    grid.set_row_spacing(4);
-    grid.set_margin_bottom(12);
+    let grid = gtk::Grid::builder()
+        .column_spacing(4)
+        .row_spacing(4)
+        .margin_bottom(12)
+        .build();
 
     let refresh_procs = build_spin(
         "Processes refresh rate (in seconds)",
@@ -197,27 +191,31 @@ pub fn show_settings_dialog(
 
     // Put the grid into the dialog's content area.
     let content_area = dialog.content_area();
-    content_area.pack_start(&grid, true, true, 0);
-    content_area.set_border_width(10);
+    content_area.append(&grid);
+    // content_area.set_border_width(10);
 
     // Finally connect to all kinds of change notification signals for the different UI widgets.
     // Whenever something is changing we directly save the configuration file with the new values.
-    refresh_procs.connect_value_changed(glib::clone!(@weak settings, @weak rfs => move |entry| {
+    refresh_procs.connect_value_changed(glib::clone!(
+    @weak settings,
+    @weak rfs.process_refresh_timeout as process_refresh_timeout
+    => move |entry| {
         let mut settings = settings.borrow_mut();
-        settings.refresh_processes_rate = (entry.value() * 1000.) as u32;
-        *rfs.borrow().process_refresh_timeout.lock().expect("failed to lock process_refresh_timeout") = settings.refresh_processes_rate;
+        settings.refresh_processes_rate = (entry.value() * 1_000.) as _;
+        *process_refresh_timeout.lock().expect("failed to lock process_refresh_timeout") =
+            settings.refresh_processes_rate;
         settings.save();
     }));
-    refresh_network.connect_value_changed(glib::clone!(@weak settings, @weak rfs => move |entry| {
+    refresh_network.connect_value_changed(glib::clone!(@weak settings, @weak rfs.network_refresh_timeout as network_refresh_timeout => move |entry| {
         let mut settings = settings.borrow_mut();
-        settings.refresh_network_rate = (entry.value() * 1000.) as u32;
-        *rfs.borrow().network_refresh_timeout.lock().expect("failed to lock network_refresh_timeout") = settings.refresh_network_rate;
+        settings.refresh_network_rate = (entry.value() * 1_000.) as _;
+        *network_refresh_timeout.lock().expect("failed to lock network_refresh_timeout") = settings.refresh_network_rate;
         settings.save();
     }));
-    refresh_sys.connect_value_changed(glib::clone!(@weak settings, @weak rfs => move |entry| {
+    refresh_sys.connect_value_changed(glib::clone!(@weak settings, @weak rfs.system_refresh_timeout as system_refresh_timeout => move |entry| {
         let mut settings = settings.borrow_mut();
-        settings.refresh_system_rate = (entry.value() * 1000.) as u32;
-        *rfs.borrow().system_refresh_timeout.lock().expect("failed to lock system_refresh_timeout") = settings.refresh_system_rate;
+        settings.refresh_system_rate = (entry.value() * 1_000.) as _;
+        *system_refresh_timeout.lock().expect("failed to lock system_refresh_timeout") = settings.refresh_system_rate;
         settings.save();
     }));
 
@@ -226,5 +224,5 @@ pub fn show_settings_dialog(
     });
 
     dialog.set_resizable(false);
-    dialog.show_all();
+    dialog.show();
 }
